%define anolis_release 1

Name:       miniz
Version:    2.2.0
Release:    %{anolis_release}%{dist}

Summary:    Compression library implementing the zlib and Deflate
# examples/example1.c:  Unlicense (refers to "unlicense" statement at the end
#                       of tinfl.c from miniz-1.15)
# examples/example2.c:  Unlicense
# examples/example3.c:  Unlicense
# examples/example4.c:  Unlicense
# examples/example5.c:  Unlicense ("Public domain. See unlicense statement")
# examples/example6.c:  Unlicense
# LICENSE:  MIT text
# miniz.c:  MIT
# miniz.h:  Unlicense (See "unlicense" statement at the end of this file.)
# readme.md:    MIT
License:    MIT AND Unlicense
URL:        https://github.com/richgel999/%{name}
Source0:    https://github.com/richgel999/%{name}/releases/download/%{version}/%{name}-%{version}.zip
# Adjust examples for building against a system miniz library,
# not suitable for upstream that prefers a copy-lib approach.
Patch0:     miniz-2.2.0-Examples-to-include-system-miniz.h.patch
Patch1:     miniz-2.2.0-Fix-use-of-uninitialized-memory-in-tinfl_decompress_.patch
Patch2:     miniz-2.2.0-Fix-unaligned-pointer-access.patch
Patch3:     miniz-2.2.0-Fix-MZ_ZIP_GENERAL_PURPOSE_BIT_FLAG_UTF8-not-being-s.patch
Patch4:     miniz-2.2.0-tinfl_decompress-avoid-NULL-ptr-arithmetic-UB.patch
Patch5:     miniz-2.2.0-miniz_zip-fix-mz_zip_reader_extract_to_heap-to-read-.patch

BuildRequires:  coreutils
BuildRequires:  diffutils
BuildRequires:  gcc
BuildRequires:  sed
BuildRequires:  unzip

%description
Miniz is a lossless, high performance data compression library in a single
source file that implements the zlib (RFC 1950) and Deflate (RFC 1951)
compressed data format specification standards. It supports the most commonly
used functions exported by the zlib library, but is a completely independent
implementation so zlib's licensing requirements do not apply. It also
contains simple to use functions for writing PNG format image files and
reading/writing/appending ZIP format archives. Miniz's compression speed has
been tuned to be comparable to zlib's, and it also has a specialized real-time
compressor function designed to compare well against fastlz/minilzo.'

%package devel
Summary:    Development files for the %{name} library
Requires:   %{name} = %{version}-%{release}

%description devel
Header files for developing applications that use the %{name} library.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -c -T -n %{name}-%{version}
unzip -e '%{SOURCE0}'
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
# Normalize end-of-lines
sed -e 's/\r$//' ChangeLog.md > ChangeLog.md.new
touch -r ChangeLog.md ChangeLog.md.new
mv ChangeLog.md.new ChangeLog.md

%global soname lib%{name}.so.0.2

%build
%{build_cc} %{optflags} -fPIC -DPIC -D_LARGEFILE64_SOURCE=1 -D_FILE_OFFSET_BITS=64 \
    %{name}.c -c -o %{name}.o
%{build_cc} %{?__global_ldflags} -fPIC -shared -Wl,-soname,%{soname} \
    %{name}.o -o %{soname}
ln -s %{soname} lib%{name}.so
# Build examples against the library
pushd examples
for EXAMPLE in *.c; do
    EXAMPLE=${EXAMPLE%.c}
    %{build_cc} %{optflags} -D_LARGEFILE64_SOURCE=1 -D_FILE_OFFSET_BITS=64 \
        -I.. "${EXAMPLE}.c" -c -o "${EXAMPLE}.o"
    case "$EXAMPLE" in
        example6)
            %{build_cc} %{?__global_ldflags} "${EXAMPLE}.o" -L.. -l%{name} -lm -o "$EXAMPLE"
            ;;
        *)
            %{build_cc} %{?__global_ldflags} "${EXAMPLE}.o" -L.. -l%{name} -o "$EXAMPLE"
            ;;
    esac
done

%check
pushd examples
for EXAMPLE in *.c; do
    EXAMPLE=${EXAMPLE%.c}
    case "$EXAMPLE" in
        example3)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" c ../readme.md readme.md.z
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" d readme.md.z readme.md
            cmp ../readme.md readme.md
            ;;
        example4)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" readme.md.z readme.md
            cmp ../readme.md readme.md
            ;;
        example5)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" c ../readme.md readme.md.z
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" d readme.md.z readme.md
            cmp ../readme.md readme.md
            ;;
        *)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}"
            ;;
    esac
done

%install
install -d '%{buildroot}/%{_libdir}'
install %{soname} '%{buildroot}/%{_libdir}'
ln -s %{soname} '%{buildroot}/%{_libdir}/lib%{name}.so'
install -d '%{buildroot}/%{_includedir}'
install -m 0644 %{name}.h '%{buildroot}/%{_includedir}'

%generate_compatibility_deps

%files
%license LICENSE
%dir %{abidir}
%{_libdir}/%{soname}
%{abidir}/libminiz.dump

%files devel
%doc examples/*.c
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so

%files doc
%doc ChangeLog.md readme.md

%changelog
* Thu Mar 30 2023 happy_orange <songnannan@linux.alibaba.com> - 2.2.0-1
- rollback to 2.2.0

* Tue Mar 28 2023 yuanhui <yuanhui@linux.alibaba.com> - 3.0.2-1
- Init package from upstream
